function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import Lambda from 'aws-sdk/clients/lambda';
import fs from 'fs';
import path from 'path';
import request from 'request';
import crypto from 'crypto';
import mime from 'mime-types';

const createPresignedPut = async ({
  uploaderArn,
  deploymentId,
  encryptedDeploymentId
}, dir) => {
  const lambda = new Lambda();
  const result = await lambda.invoke({
    FunctionName: uploaderArn,
    Payload: JSON.stringify({
      type: 'put',
      deploymentId,
      encryptedDeploymentId,
      dir
    })
  }).promise();
  const {
    FunctionError,
    Payload: ResponsePayload
  } = result;

  if (FunctionError != null) {
    const {
      errorMessage
    } = ResponsePayload == null ? {
      errorMessage: 'Unknown error'
    } : JSON.parse(ResponsePayload.toString());
    throw new Error(errorMessage);
  }

  return ResponsePayload != null ? JSON.parse(ResponsePayload.toString()) : null;
};

export const upload = (pool, uploadUrl, filePath) => {
  const fileSizeInBytes = fs.statSync(filePath).size;
  const fileStream = fs.createReadStream(filePath);
  const contentType = mime.contentType(path.extname(filePath)) || 'text/plain; charset=utf-8';
  return new Promise((resolve, reject) => request.put({
    headers: {
      'Content-Length': fileSizeInBytes,
      'Content-Type': contentType
    },
    uri: uploadUrl,
    body: fileStream
  }, (error, _, body) => {
    error ? reject(error) : body ? reject(body) : resolve();
  }));
};

const createPresignedPost = async ({
  uploaderArn,
  deploymentId,
  encryptedDeploymentId
}, dir) => {
  const lambda = new Lambda();
  const {
    FunctionError,
    Payload: ResponsePayload
  } = await lambda.invoke({
    FunctionName: uploaderArn,
    Payload: JSON.stringify({
      type: 'post',
      deploymentId,
      encryptedDeploymentId,
      dir
    })
  }).promise();

  if (FunctionError != null) {
    const {
      errorMessage
    } = ResponsePayload == null ? {
      errorMessage: 'Unknown error'
    } : JSON.parse(ResponsePayload.toString());
    throw new Error(errorMessage);
  }

  return ResponsePayload != null ? JSON.parse(ResponsePayload.toString()) : null;
};

export const uploadFormData = (pool, form, filePath) => {
  const fileStream = fs.createReadStream(filePath);
  const contentType = mime.contentType(path.extname(filePath)) || 'text/plain; charset=utf-8';
  form.fields.key = form.fields.Key;
  delete form.fields.Key;
  return new Promise((resolve, reject) => request.post({
    url: form.url,
    formData: _objectSpread({}, form.fields, {
      'Content-Type': contentType,
      file: fileStream
    })
  }, error => {
    error ? reject(error) : resolve();
  }));
};
export const createToken = ({
  encryptedDeploymentId
}, {
  dir,
  expireTime = 3600
}) => {
  const payload = Buffer.from(JSON.stringify({
    encryptedDeploymentId,
    dir,
    expireTime: Date.now() + expireTime * 1000
  })).toString('base64').replace(/=/g, '');
  const signature = crypto.createHmac('md5', encryptedDeploymentId).update(payload).digest('hex');
  return `${payload}*${signature}`;
};

const createUploadAdapter = config => {
  const {
    deploymentId,
    CDN,
    encryptedDeploymentId
  } = config;
  return Object.freeze({
    createPresignedPut: createPresignedPut.bind(null, config),
    upload: upload.bind(null, config),
    createPresignedPost: createPresignedPost.bind(null, config),
    uploadFormData: uploadFormData.bind(null, config),
    createToken: createToken.bind(null, config),
    deploymentId,
    CDN,
    encryptedDeploymentId
  });
};

export default createUploadAdapter;
//# sourceMappingURL=index.js.map