"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = exports.createToken = exports.uploadFormData = exports.upload = void 0;

var _lambda = _interopRequireDefault(require("aws-sdk/clients/lambda"));

var _fs = _interopRequireDefault(require("fs"));

var _path = _interopRequireDefault(require("path"));

var _request = _interopRequireDefault(require("request"));

var _crypto = _interopRequireDefault(require("crypto"));

var _mimeTypes = _interopRequireDefault(require("mime-types"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

const createPresignedPut = async ({
  uploaderArn,
  deploymentId,
  encryptedDeploymentId
}, dir) => {
  const lambda = new _lambda.default();
  const result = await lambda.invoke({
    FunctionName: uploaderArn,
    Payload: JSON.stringify({
      type: 'put',
      deploymentId,
      encryptedDeploymentId,
      dir
    })
  }).promise();
  const {
    FunctionError,
    Payload: ResponsePayload
  } = result;

  if (FunctionError != null) {
    const {
      errorMessage
    } = ResponsePayload == null ? {
      errorMessage: 'Unknown error'
    } : JSON.parse(ResponsePayload.toString());
    throw new Error(errorMessage);
  }

  return ResponsePayload != null ? JSON.parse(ResponsePayload.toString()) : null;
};

const upload = (pool, uploadUrl, filePath) => {
  const fileSizeInBytes = _fs.default.statSync(filePath).size;

  const fileStream = _fs.default.createReadStream(filePath);

  const contentType = _mimeTypes.default.contentType(_path.default.extname(filePath)) || 'text/plain; charset=utf-8';
  return new Promise((resolve, reject) => _request.default.put({
    headers: {
      'Content-Length': fileSizeInBytes,
      'Content-Type': contentType
    },
    uri: uploadUrl,
    body: fileStream
  }, (error, _, body) => {
    error ? reject(error) : body ? reject(body) : resolve();
  }));
};

exports.upload = upload;

const createPresignedPost = async ({
  uploaderArn,
  deploymentId,
  encryptedDeploymentId
}, dir) => {
  const lambda = new _lambda.default();
  const {
    FunctionError,
    Payload: ResponsePayload
  } = await lambda.invoke({
    FunctionName: uploaderArn,
    Payload: JSON.stringify({
      type: 'post',
      deploymentId,
      encryptedDeploymentId,
      dir
    })
  }).promise();

  if (FunctionError != null) {
    const {
      errorMessage
    } = ResponsePayload == null ? {
      errorMessage: 'Unknown error'
    } : JSON.parse(ResponsePayload.toString());
    throw new Error(errorMessage);
  }

  return ResponsePayload != null ? JSON.parse(ResponsePayload.toString()) : null;
};

const uploadFormData = (pool, form, filePath) => {
  const fileStream = _fs.default.createReadStream(filePath);

  const contentType = _mimeTypes.default.contentType(_path.default.extname(filePath)) || 'text/plain; charset=utf-8';
  form.fields.key = form.fields.Key;
  delete form.fields.Key;
  return new Promise((resolve, reject) => _request.default.post({
    url: form.url,
    formData: _objectSpread({}, form.fields, {
      'Content-Type': contentType,
      file: fileStream
    })
  }, error => {
    error ? reject(error) : resolve();
  }));
};

exports.uploadFormData = uploadFormData;

const createToken = ({
  encryptedDeploymentId
}, {
  dir,
  expireTime = 3600
}) => {
  const payload = Buffer.from(JSON.stringify({
    encryptedDeploymentId,
    dir,
    expireTime: Date.now() + expireTime * 1000
  })).toString('base64').replace(/=/g, '');

  const signature = _crypto.default.createHmac('md5', encryptedDeploymentId).update(payload).digest('hex');

  return `${payload}*${signature}`;
};

exports.createToken = createToken;

const createUploadAdapter = config => {
  const {
    deploymentId,
    CDN,
    encryptedDeploymentId
  } = config;
  return Object.freeze({
    createPresignedPut: createPresignedPut.bind(null, config),
    upload: upload.bind(null, config),
    createPresignedPost: createPresignedPost.bind(null, config),
    uploadFormData: uploadFormData.bind(null, config),
    createToken: createToken.bind(null, config),
    deploymentId,
    CDN,
    encryptedDeploymentId
  });
};

var _default = createUploadAdapter;
exports.default = _default;
//# sourceMappingURL=index.js.map